@@ -75,7 +75,15 @@ sub csv_parse {
     my $last_pos = 0;
 
     my @fields;
-    while ( $str =~ / (?:^|,) (?: "(.*?)"(?=,|$) | (\d*)(?=,|$) ) /xsg ) {
+    while (
+        $str =~ / (?:^|,) 
+          (?: ""
+            | "(.*?)(?<![^"]")"
+            | (\d*)
+          )
+          (?=,|$) /xsg
+      )
+    {
         my $field = $1 || $2;
         $field ||= ( $& =~ /^,?""$/ ? "" : undef );
 
